<?php
/*
 * @package protopress, Copyright Rohit Tripathi, rohitink.com
 * This file contains Custom Theme Related Functions.
 */
/*
* @package forest, Copyright Rohit Tripathi, rohitink.com
* This file contains Custom Theme Related Functions.
*/
//Import Admin Modules
require get_template_directory() . '/framework/admin_modules/register_styles.php';
require get_template_directory() . '/framework/admin_modules/register_widgets.php';
require get_template_directory() . '/framework/admin_modules/theme_setup.php';
require get_template_directory() . '/framework/admin_modules/admin_styles.php';
/*
** Walkers for Navigation menus
*/ 
//Supports Menu Desc and Icons Both 
class Protopress_Menu_With_Description extends Walker_Nav_Menu {
	function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';

		$fontIcon = ! empty( $item->attr_title ) ? ' <i class="' . esc_attr( $item->attr_title ) .'">' : '';
		$attributes = ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
		$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>'.$fontIcon.'</i>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '<br /><span class="menu-desc">' . $item->description . '</span>';
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
	}
}
//Supports Icon only. No Description.
class Protopress_Menu_With_Icon extends Walker_Nav_Menu {
	function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		
		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';

		$fontIcon = ! empty( $item->attr_title ) ? ' <i class="' . esc_attr( $item->attr_title ) .'">' : '';
		$attributes = ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
		$attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) .'"' : '';
		$attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>'.$fontIcon.'</i>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args, $id );
	}
}

/*
 * Pagination Function. Implements core paginate_links function.
 */
function protopress_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
	            $paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
	            echo '<div class="pagination"><div><ul>';
	            echo '<li><span>'. $paged . __(' of ','protopress') . $wp_query->max_num_pages .'</span></li>';
	            foreach ( $page_format as $page ) {
	                    echo "<li>$page</li>";
	            }
	           echo '</ul></div></div>';
	 }
}

  
/*
** Function to check if Sidebar is enabled on Current Page 
*/

function protopress_load_sidebar() {
	$load_sidebar = true;
	if ( get_theme_mod('protopress_disable_sidebar') ) :
		$load_sidebar = false;
	elseif( get_theme_mod('protopress_disable_sidebar_home') && is_home() )	:
		$load_sidebar = false;
	elseif( get_theme_mod('protopress_disable_sidebar_front') && is_front_page() ) :
		$load_sidebar = false;
	endif;
	
	return  $load_sidebar;
}

/*
**	Determining Sidebar and Primary Width
*/
function protopress_primary_class() {
	$sw = get_theme_mod('protopress_sidebar_width',4);
	$class = "col-md-".(12-$sw);
	
	if ( !protopress_load_sidebar() ) 
		$class = "col-md-12";
	
	echo $class;
}
add_action('protopress_primary-width', 'protopress_primary_class');

function protopress_secondary_class() {
	$sw = get_theme_mod('protopress_sidebar_width',4);
	$class = "col-md-".$sw;
	
	echo $class;
}
add_action('protopress_secondary-width', 'protopress_secondary_class');


/*
**	Helper Function to Convert Colors
*/
function protopress_hex2rgb($hex) {
   $hex = str_replace("#", "", $hex);
   if(strlen($hex) == 3) {
      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
   } else {
      $r = hexdec(substr($hex,0,2));
      $g = hexdec(substr($hex,2,2));
      $b = hexdec(substr($hex,4,2));
   }
   $rgb = array($r, $g, $b);
   return implode(",", $rgb); // returns the rgb values separated by commas
   //return $rgb; // returns an array with the rgb values
}
function protopress_fade($color, $val) {
	return "rgba(".protopress_hex2rgb($color).",". $val.")";
}


/*
** Function to Get Theme Layout 
*/
function protopress_get_blog_layout(){
	$ldir = 'framework/layouts/content';
	if (get_theme_mod('protopress_blog_layout') ) :
		get_template_part( $ldir , get_theme_mod('protopress_blog_layout') );
	else :
		get_template_part( $ldir ,'grid');	
	endif;	
}
add_action('protopress_blog_layout', 'protopress_get_blog_layout');



/*
** Load Custom Widgets
*/

require get_template_directory() . '/framework/widgets/recent-posts.php';


/**
 *	Slider Functions
**/

add_filter( 'attachment_fields_to_edit', 'store_filter', 99, 2 );
		

function store_filter( $form_fields, $post ) {
		
	$form_fields['post_title']	=	array(
		'label'	=> __('Title', 'protopress'),
		'html'	=> 	"<input type='text' class='text slide_title' value='" . get_the_title( $post->ID ) . "' /><br />",
		'input'	=> 'text',
	);
	
	$form_fields['post_content']	=	array(
		'label'	=> __('Description', 'protopress'),
		'html'	=> "<textarea style='width: 100%'></textarea>",
		'value'	=> $post->post_content
	);
	
	$form_fields['protopress_link']	=	array(
		'label'	=>	__( 'Slide link', 'protopress' ),
		'helps'	=> __('Add the URL for the Slide <b>(ProtoPress)</b>', 'protopress' ),
		'input'	=> 'text',
		'value'	=> get_post_meta( $post->ID, 'protopress_link', true ),
		'html'	=> "<input type='text' class='text protopress_link' value='" . get_post_meta( $post->ID, 'protopress_link', true ) . "' /><br />",
	);
	
	$form_fields['cta_button']	=	array(
		'label'	=> __( 'CTA Button', 'protopress'),
		'helps'	=> __( 'Enter the text to be displayed in Call To Action Button <b>(ProtoPress)</b>', 'protopress' ),
		'input'	=> 'text',
		'html'	=> "<input type='text' class='text cta_button' value='" . get_post_meta( $post->ID, 'cta_button', true ) . "' /><br />",
		'value'	=> get_post_meta( $post->ID, 'cta_button', true )
	);
 
    // We return the completed $form_fields array
    return $form_fields;
}
	
add_filter( 'attachment_fields_to_save', 'protopre_save_fields', 11, 2 );
	
function protopre_save_fields( $post, $attachment ) {
	
	if ( isset( $attachment['protopress_link'] ) )
		update_post_meta( $post['ID'], 'protopress_link', $attachment['protopress_link'] );
	
	if ( isset( $attachment['cta_button'] ) )
		update_post_meta( $post['ID'], 'cta_button', $attachment['cta_button'] );
		
	return $post;
}
	
/**
 * Save values of Author Name and URL in media uploader modal via AJAX
 */

add_action('wp_ajax_save-attachment-compat', 'protopress_meta_save_ajax', 0, 1);

function protopress_meta_save_ajax() {

    $post_id = $_POST['id'];

    if( isset( $_POST['attachments'][$post_id]['protopress_link'] ) )
        update_post_meta( $post_id, 'protopress_link', $_POST['attachments'][$post_id]['protopress_link'] );

    if( isset( $_POST['attachments'][$post_id]['cta_button'] ) )
        update_post_meta( $post_id, 'cta_button', $_POST['attachments'][$post_id]['cta_button'] );

    clean_post_cache($post_id);

}


function slider_vars() {
	$args	=	array(
				'pause_time'	=>	esc_html( get_theme_mod('protopress_slider_pause') ),
				'speed'			=>	esc_html( get_theme_mod( 'protopress_slider_speed' ) ),
				'pager'			=>	esc_html( get_theme_mod( 'protopress_slider_pager' ) ),
				'arrow'			=>	esc_html( get_theme_mod( 'protopress_slider_arrow' ) ),
				'autoplay'		=>	esc_html( get_theme_mod( 'protopress_slider_autoplay') ),
				'effect'		=>	esc_html( get_theme_mod( 'protopress_slider_effect' ) )
			);
	
	wp_localize_script( 'protopress-custom-js', 'protopress', $args );
}
add_action( 'wp_enqueue_scripts', 'slider_vars' );